--!parent
--!encoding=utf-8

--****************************************************************************
-- @file      LSW CORE LIB: FILESYSTEM
-- @author    Valentin Schmidt
-- @version   0.2
-- @requires  xtra("BinFile")
--****************************************************************************

property $

----------------------------------------
-- @constructor
----------------------------------------
on new (me)
  $.loadXtras(me.libdir, ["BinFile.x32"], ["BinFile.xtra"])
  return me
end

-- files

----------------------------------------
-- Copies file
-- @param {string} fromFn
-- @param {string} toFn
-- @return {bool}
----------------------------------------
on fileCopy (me, fromFn, toFn)
  return bx_file_copy(fromFn, toFn)
end

----------------------------------------
-- Deletes file
-- @param {string} fn
-- @return {bool}
----------------------------------------
on fileDelete (me, fn)
  return bx_file_delete(fn)
end

----------------------------------------
-- Checks if file exists
-- @param {string} fn
-- @return {bool}
----------------------------------------
on fileExists (me, fn)
  return (bx_exists(fn)=1)
end

----------------------------------------
-- Moves file
-- @param {string} fn
-- @return {bool}
----------------------------------------
on fileMove (me, fromFn, toFn)
  return bx_rename(fromFn, toFn)
end

----------------------------------------
-- Recycles file
-- @param {string} fn
-- @return {bool}
----------------------------------------
on fileRecycle (me, fn)
  return bx_file_recycle(fn)
end

----------------------------------------
-- Renames file
-- @param {string} fromFn
-- @param {string} toFn
-- @return {bool}
----------------------------------------
on fileRename (me, fromFn, toFn)
  return bx_rename(fromFn, toFn)
end

----------------------------------------
-- Returns file size
-- @param {string} fn
-- @return {integer}
----------------------------------------
on fileSize (me, fn)
  return bx_file_size(fn)
end

----------------------------------------
-- Truncates file
-- @param {string} fn
-- @param {integer} size
-- @return {bool}
----------------------------------------
on fileTruncate (me, fn, size)
  return bx_file_truncate(fn, size)
end

-- folders

----------------------------------------
-- Copies folder
-- @param {string} fromFn
-- @param {string} toFn
-- @return {bool}
----------------------------------------
on folderCopy (me, fromFn, toFn)
  return bx_folder_copy(fromFn, toFn)
end

----------------------------------------
-- Creates folder
-- @param {string} foldername
-- @return {bool}
----------------------------------------
on folderCreate (me, foldername)
  return bx_folder_create(foldername)
end

----------------------------------------
-- Deletes folder
-- @param {string} foldername
-- @return {bool}
----------------------------------------
on folderDelete (me, foldername)
  return bx_folder_delete(foldername)
end

----------------------------------------
-- Checks if folder exists
-- @param {string} fn
-- @return {bool}
----------------------------------------
on folderExists (me, foldername)
  return (bx_exists(foldername)=2)
end

----------------------------------------
-- Returns list of files and folders
-- @param {string} folderName
-- @return {list}
----------------------------------------
on folderList (me, folderName)
  return bx_folder_get_contents(folderName)
end

----------------------------------------
-- Renames folder
-- @param {string} fromFn
-- @param {string} toFn
-- @return {bool}
----------------------------------------
on folderRename (me, fromFn, toFn)
  return bx_rename(fromFn, toFn)
end
